<template>
  <el-container>
    <el-dialog title="系统集成基础信息" v-dialogDrag :visible.sync="showSubmitDialog" class="avue-dialog avue-dialog--top" append-to-body @close="closeSubmitDialog" width="1000px"
               style="height: 100vh;" top="-5%">
      <el-form ref="form" :model="formData" show-message="true" inline size="medium" label-suffix=":"
               class="dockingForm" :rules="rules" @resetFields="resetForm" status-icon="true">
        <el-form-item label="接口类型" prop="interfaceType">
          <el-select v-model="formData.interfaceType" placeholder="请选择接口类型" @change="typeSelectChange">
            <el-option v-for="item in interfaceTypeList" :key="item.value" :label="item.label" :value="item.value">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="参数类型" prop="paramType">
          <el-select v-model="formData.paramType" placeholder="请选择参数类型" @change="typeSelectChange">
            <el-option v-for="item in paramTypeList" :key="item.value" :label="item.label" :value="item.value">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="返回值类型" prop="returnType">
          <el-select v-model="formData.returnType" placeholder="请选择返回值类型" @change="typeSelectChange">
            <el-option v-for="item in returnTypeList" :key="item.value" :label="item.label" :value="item.value">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="推送类型" prop="pushType">
          <el-select v-model="formData.pushType" placeholder="请选择推送类型" @change="typeSelectChange">
            <el-option v-for="item in pushTypeList" :key="item.value" :label="item.label" :value="item.value">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="分类选择" prop="classifyName">
          <vciWebRefer
            :referConfig="{
                  title: '分类选择',
                  showField: 'classifyName',
                  field: 'classifyOid',
                  fieldMap:{'classifyId':'id'},
                  placeholder: '请选择分类选择',
                  options: {isMuti: false, type: 'tree', url: 'api/ubcs-code/codeClassify/referTree'},
                }"
            :value="formData.classifyOid"
            :text="formData.classifyName"
            :disabled="false"
            :display="true"
            @setReferValue="setReferValue"
          ></vciWebRefer>
        </el-form-item>
        <el-form-item label="推送系统" prop="sourceSysName">
          <vciWebRefer
            :referConfig="{
                  title: '推送系统',
                  showField: 'sourceSysName',
                  field: 'sourceSystemOid',
                  fieldMap:{'sourceSysId':'id'},
                  placeholder: '请选择推送系统',
                  options: {isMuti: false, type: 'default', url: 'api/ubcs-code/codeClassify/referTree'},
                }"
            :value="formData.sourceSystemOid"
            :text="formData.sourceSysName"
            :disabled="false"
            :display="true"
            @setReferValue="setReferValue"
          ></vciWebRefer>
        </el-form-item>
        <el-form-item label="系统描述" >
          <el-input type="textarea" :rows="2" v-model="formData.description"></el-input>
        </el-form-item>
        <el-form-item label="请求方式" prop="requestMethod">
          <el-select v-model="formData.requestMethod" placeholder="请选择请求方式" @change="typeSelectChange">
            <el-option v-for="item in requestMethodList" :key="item.value" :label="item.label" :value="item.value">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="请求地址" prop="requestUrl">
          <el-input v-model="formData.requestUrl" type="text"></el-input>
        </el-form-item>
        <el-form-item label="接口函数" prop="interfaceFunction">
          <el-input v-model="formData.interfaceFunction"></el-input>
        </el-form-item>
        <el-form-item label="命名空间" prop="nameSpace">
          <el-input v-model="formData.namespace"></el-input>
        </el-form-item>
        <el-form-item label="soapaction" prop="soapaction">
          <el-input v-model="formData.soapaction" ></el-input>
        </el-form-item>
        <el-form-item label="参数名称" prop="targName">
          <el-input v-model="formData.targName" ></el-input>
        </el-form-item>
        <el-form-item label="cxfaxis" prop="cxfaxis">
          <el-input v-model="formData.soapaction" ></el-input>
        </el-form-item>
        <el-form-item label="类路径" prop="classPath">
          <el-input v-model="formData.classPath" ></el-input>
        </el-form-item>
        <el-tabs v-model="activeName" @tab-click="handleClick" stretch="true">
          <el-tab-pane label="参数对象" name="paramTab">
            <avue-crud :option="param.option"
                       :data="param.data"
                       v-model="formData.sysIntParamVOs"
                       ref="paramcrud">
              <template slot="menuLeft">
                <el-button type="primary"
                           size="small"
                           plain
                           icon="el-icon-plus"
                           @click="handleParamAdd">添加行
                </el-button>
              </template>
              <template slot-scope="scope" slot="menu">
                <el-button type="text"
                           icon="el-icon-delete"
                           size="small"
                           @click="handleParamDel(scope.row)">移除
                </el-button>
              </template>
            </avue-crud>
          </el-tab-pane>
          <el-tab-pane label="header对象" name="headerTab">
            <avue-crud :option="header.option"
                       :data="header.data"
                       v-model="formData.sysIntHeaderVOs"
                       ref="paramcrud">
              <template slot="menuLeft">
                <el-button type="primary"
                           size="small"
                           plain
                           icon="el-icon-plus"
                           @click="handleHeaderAdd">添加行
                </el-button>
              </template>
              <template slot-scope="scope" slot="menu">
                <el-button type="text"
                           icon="el-icon-delete"
                           size="small"
                           @click="handleHeaderDel(scope.row)">移除
                </el-button>
              </template>
            </avue-crud>
          </el-tab-pane>
        </el-tabs>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitAttribute">确定</el-button>
        <el-button @click="cancelSubmit">取消</el-button>
      </div>
    </el-dialog>

  </el-container>
</template>

<script>
import { getDictionary, getParentList } from '@/api/omd/enum'
import {add,edit} from "@/api/docking/info"
import vciWebRefer from "@/components/refer/vciWebRefer.vue";

export default {
  name: 'infoForm',
  props: {
    formData: {
      type: Object
    },
  },
  components: { vciWebRefer },
  data() {
    return {
      showSubmitDialog: false,
      //接口类型下拉
      interfaceTypeList: [{
        label: 'webService', value: 'webService'
      }, {
        label: '类路径', value: 'classPath'
      }, {
        label: 'Http', value: 'http'
      }],
      //参数类型下拉
      paramTypeList:[ {
          label: 'xml', value: 'xml'
        }, {
          label: 'Json', value: 'json'
        }],
      //返回值类型下拉
      returnTypeList:[ {
        label: 'xml', value: 'xml'
      }, {
        label: 'Json', value: 'json'
      }],
      //推送类型
      pushTypeList: [{key: '1', value: '数据推送'},
        {key: '2', value: '分类推送'},
        {key: '3', value: '编码申请'},
        {key: '4', value: '编码更改（状态、回收）'},
        {key: '5', value: '分类查询'},
        {key: '6', value: '含规则信息的分类查询'},
        {key: '7', value: '数据查询'}],
      //请求方式
      requestMethodList:[{key: 'post', value: 'post'},
        {key: 'get', value: 'get'},
        {key: 'delete', value: 'delete'},
        {key: 'put', value: 'put'}],
      // 默认的页签
      activeName: 'paramTab',
      // 属性类型下拉框数据
      typeList: [],
      // 参照下拉框是否可用
      referToFlag: true,
      // 表单校验规则
      rules: {
        paramType: [
          {required: true, message: '请选择参数类型', trigger: 'blur'}
        ],
        returnType: [
          {required: true, message: '请选择返回值类型', trigger: 'blur'}
        ],
        pushType: [
          {required: true, message: '请选择推送类型', trigger: 'change'}
        ],
        classifyName: [
          {required: true, message: '请选择推送系统', trigger: 'blur'}
        ],
        sourceSysName: [
          {required: true, message: '请选择分类选择', trigger: 'blur'}
        ],
        classPath: [
          {required: true, message: '请输入类路径', trigger: 'blur'}
        ],
        requestMethod: [
          {required: true, message: '请选择请求方式', trigger: 'blur'}
        ],
        requestUrl: [
          {required: true, message: '请输入请求地址', trigger: 'blur'}
        ],
        interfaceFunction: [
          {required: true, message: '请输入接口函数', trigger: 'blur'}
        ],
        nameSpace: [
          {required: true, message: '请输入命名空间', trigger: 'blur'}
        ],
        soapaction: [
          {required: true, message: '请输入soapaction', trigger: 'blur'}
        ],
        targName: [
          {required: true, message: '请输入参数名称', trigger: 'blur'}
        ],
        cxfaxis: [
          {required: true, message: '请输入cxfaxis', trigger: 'blur'}
        ]
      },
      // 表格配置
      param: {
        option: {
          height: 200,
          addBtn: false,
          viewBtn: false,
          delBtn: false,
          editBtn: false,
          refreshBtn: false,
          columnBtn: false,
          menu: false,
          border: true,
          searchShowBtn: false,
          column: [{
            label: '参数名',
            prop: 'paramKey'
          }, {
            label: '参数值',
            prop: 'paramValue'
          }, {
            label: '是否使用',
            prop: 'usedFlag',
            dicData: [{
              label: '是', value: 'true'
            }, {
              label: '否', value: 'false'
            }]
          }]
        },
        data: [],
        selectRow: {}
      },
      // 枚举参照表格配置
      header: {
        option: {
          height: 200,
          addBtn: false,
          viewBtn: false,
          delBtn: false,
          editBtn: false,
          refreshBtn: false,
          menu: false,
          border: true,
          searchShowBtn: false,
          column: [{
            label: '头参数名称',
            prop: 'headerKey'
          }, {
            label: '头参数值',
            prop: 'headerValue'
          }, {
            label: '是否使用',
            prop: 'usedFlag',
            dicData: [{
              label: '是', value: 'true'
            }, {
              label: '否', value: 'false'
            }]
          }],
          data: [],
          // 选定行
          selectRow: ''
        },
        dictEnums: []
      }
    }
  },
  created() {
    //this.geDictData('interfaceType', this.interfaceTypeList)

  },
  methods: {
    closeSubmitDialog() {
      this.resetForm();
      this.showSubmitDialog = false;
    },
    resetForm() {
      this.formData = {
        nullable: true,
        referTypeKey: '',
      };
      this.referToFlag = true;
      this.$refs.form.resetFields();
      this.dictEnums = [];
    },
    setReferValue(data) {
      if (data.field) {
        this.formData[data.field] = data.value || "";
        this.formData[data.showField] = data.text || "";
      }
      if (data.fieldMap) {
        //说明需要映射
        for (let key in data.fieldMap) {
          let mapFields = data.fieldMap[key].split(",");
          let value = [];
          data.rawData.forEach(_item => {
            var temp;
            if (!_item.attributes) {
              _item.attributes = _item;
            }
            if (mapFields.length == 1) {
              var mapField = mapFields[0];
              if (mapField.indexOf("attribute.") > -1) {
                temp = _item['attributes'][mapField.subString("attribute.".length)];
              } else {
                temp = _item['attributes'][mapField] || _item[mapField];
              }
            } else {
              //有多个
              var mutiTemp = [];
              layui.each(mapFields, function (_indexField, _itemField) {
                if (_itemField.indexOf("attribute.") > -1) {
                  mutiTemp.push(_item['attributes'][_itemField.subString("attribute.".length)]);
                } else {
                  mutiTemp.push(_item['attributes'][_itemField] || _item[_itemField]);
                }
              });
              temp = mutiTemp.join(' ');
            }
            if (temp != null && temp != '') {
              value.push(temp);
            }
          })
          this.formData[key] = value.join(',');
        }
      }
    }
    ,
    submitAttribute() {
      const that = this;
      this.$refs.form.validate(function (pass, field) {
        if (pass) {
          add(that.formData).then(res => {
            that.$message.success("保存成功");
            that.showSubmitDialog = false;
            that.formData = {};
            that.$emit('refreshTable');
          });
        } else {
          that.$message.error('必填');
        }
      })
    },
    cancelSubmit() {
      this.closeSubmitDialog();
    },
    // 属性类型下拉框选择事件
    typeSelectChange(value) {
      if (value == 'VTString') {
        this.$set(this.formData, "maxLength", 150)
      } else if (value == 'VTInteger') {
        this.$set(this.formData, "maxLength", 50)
      } else if (value == 'VTBoolean') {
        this.$set(this.formData, "maxLength", 5)
      } else if (value == 'VTDouble') {
        this.$set(this.formData, "maxLength", 26)
        this.$set(this.formData, "precision", 8)
      } else if (value == 'VTLong') {
        this.$set(this.formData, "maxLength", 150)
      } else if (value == 'VTDate' || value == 'VTTime' || value == 'VTDateTime') {
        this.$set(this.formData, "maxLength", 6)
      } else {
        this.$set(this.formData, "maxLength", 50)
      }
      this.formData.typeCode = 'attributeType';
      this.formData.typeKey = value;
    },
    // 异步获取字典数据
    geDictData(dictKey, list) {
      getDictionary({code: dictKey}).then((res) => {
        if (res.data && res.data.code === 200) {
          let dictData = (res.data.data || []).map((itm) => {
            itm.value = itm.dictValue;
            itm.key = itm.dictKey;
            return itm;
          });
          list = dictData;
        }
      });
    },
    handleClick(tab) {
      // 因为只能参照和枚举二选一。所以在切换的时候把属性给清空。
      if (tab.name === 'enumTab') {
        this.enumInitFlag = true;
        this.referInitFlag = false;
      } else {
        this.enumInitFlag = false;
        this.referInitFlag = true;
      }
    }
  }
}
</script>

<style>
.btmTable>.el-card:nth-of-type(2)>.el-card__body>.avue-crud__menu {
  display: none !important;
}

.enumTable>.el-card:nth-of-type(2)>.el-card__body>.avue-crud__menu {
  display: none !important;
}
.dockingForm .el-form-item__label{width: 130px;}
.dockingForm .el-form-item__content .el-input>.el-input__inner,.dockingForm .el-input-number--medium {
  width: 300px !important;
}
.dockingForm .el-form-item__content{
  width :300px !important;
}
</style>
